Subset: owl - LinkML Model

# Subset: owl

Set of slots that appear in the OWL representation of a model

URI: linkml:owl

### Classes

### Mixins

### Slots

- comments - notes and comments about an element intended for external consumption
- description - a description of the element's purpose and use
- examples - example usages of an element
- generation_date - date and time that the schema was loaded/generated
- license - license for the schema
- metamodel_version - Version of the metamodel used to load the schema
- name - the unique name of the element within the context of the schema. Name is combined with the default prefix to form the globally unique subject of the target class.
- notes - editorial notes about an element intended for internal consumption
- see_also - a reference
- source_file - name, uri or description of the source of the schema
- source_file_date - modification date of the source of the schema
- source_file_size - size in bytes of the source of the schema
- title - the official title of the element
- version - particular version of schema

### Types

### Enums